@@ -2,7 +2,7 @@ build_rkhs <-
   function(x, type, knots, xrng){
     # build reproducing kernel Hilbert space components
     # Nathaniel E. Helwig (helwig@umn.edu)
-    # last updated: 2019-10-30
+    # last updated: 2021-04-09
     
     ### initializations
     nxvar <- length(x)
@@ -39,14 +39,14 @@ build_rkhs <-
       } else if(tj == "nom"){
         
         # nominal smoothing spline
-        Xcont[[j]] <- basis_nom(x = x[[j]], knots = knots[[j]], K = xrng[[j]][2])
-        Qcont[[j]] <- penalty_nom(x = knots[[j]], K = xrng[[j]][2])
+        Xcont[[j]] <- basis.nom(x = x[[j]], knots = knots[[j]], K = xrng[[j]][2])
+        Qcont[[j]] <- penalty.nom(x = knots[[j]], K = xrng[[j]][2])
         
       } else if(tj == "ord"){
         
         # ordinal smoothing spline
-        Xcont[[j]] <- basis_ord(x = x[[j]], knots = knots[[j]], K = xrng[[j]][2])
-        Qcont[[j]] <- penalty_ord(x = knots[[j]], K = xrng[[j]][2])
+        Xcont[[j]] <- basis.ord(x = x[[j]], knots = knots[[j]], K = xrng[[j]][2])
+        Qcont[[j]] <- penalty.ord(x = knots[[j]], K = xrng[[j]][2])
         
       } else if(any(tj == ss.types)){
         
@@ -55,11 +55,11 @@ build_rkhs <-
                     ifelse(tj == "cub" | tj == "per.cub" | tj == "per", 2L, 3L))
         periodic <- ifelse(any(tj == c("per.lin", "per.cub", "per.qui", "per")), TRUE, FALSE)
         if(periodic | tj == "lin"){
-          Xcont[[j]] <- basis_poly(x = x[[j]], knots = knots[[j]], m = m, xmin = xrng[[j]][1], xmax = xrng[[j]][2], periodic = periodic)
-          Qcont[[j]] <- penalty_poly(x = knots[[j]], m = m, xmin = xrng[[j]][1], xmax = xrng[[j]][2], periodic = periodic)
+          Xcont[[j]] <- basis.poly(x = x[[j]], knots = knots[[j]], m = m, xmin = xrng[[j]][1], xmax = xrng[[j]][2], periodic = periodic)
+          Qcont[[j]] <- penalty.poly(x = knots[[j]], m = m, xmin = xrng[[j]][1], xmax = xrng[[j]][2], periodic = periodic)
         } else {
-          X <- basis_poly(x = x[[j]], knots = knots[[j]], m = m, xmin = xrng[[j]][1], xmax = xrng[[j]][2], periodic = periodic)
-          Q <- basis_poly(x = knots[[j]], knots = knots[[j]], m = m, xmin = xrng[[j]][1], xmax = xrng[[j]][2], periodic = periodic)
+          X <- basis.poly(x = x[[j]], knots = knots[[j]], m = m, xmin = xrng[[j]][1], xmax = xrng[[j]][2], periodic = periodic)
+          Q <- basis.poly(x = knots[[j]], knots = knots[[j]], m = m, xmin = xrng[[j]][1], xmax = xrng[[j]][2], periodic = periodic)
           nulldim <- ncol(Q) - nrow(Q)
           nullnames <- xnames[j]
           if(m == 3L) nullnames <- c(nullnames, paste0(xnames[j], "^2"))
@@ -75,8 +75,8 @@ build_rkhs <-
         
         # spherical spline
         m <- ifelse(tj == "sph.lin", 1L, ifelse(tj == "sph.cub" | tj == "sph", 2L, 3L))
-        Xcont[[j]] <- basis_sph(x = x[[j]], knots = knots[[j]], m = m)
-        Qcont[[j]] <- penalty_sph(x = knots[[j]], m = m)
+        Xcont[[j]] <- basis.sph(x = x[[j]], knots = knots[[j]], m = m)
+        Qcont[[j]] <- penalty.sph(x = knots[[j]], m = m)
         
       } else {
         
@@ -84,11 +84,11 @@ build_rkhs <-
         xdim <- ncol(as.matrix(x[[j]]))
         m <- ifelse(tj == "tps.lin", 1L, ifelse(tj == "tps.cub" | tj == "tps", 2L, 3L))
         if(tj == "tps.lin"){
-          Xcont[[j]] <- basis_tps(x = x[[j]], knots = knots[[j]], m = m)
-          Qcont[[j]] <- penalty_tps(x = knots[[j]], m = m)
+          Xcont[[j]] <- basis.tps(x = x[[j]], knots = knots[[j]], m = m)
+          Qcont[[j]] <- penalty.tps(x = knots[[j]], m = m)
         } else {
-          X <- basis_tps(x = x[[j]], knots = knots[[j]], m = m)
-          Q <- basis_tps(x = knots[[j]], knots = knots[[j]], m = m)
+          X <- basis.tps(x = x[[j]], knots = knots[[j]], m = m)
+          Q <- basis.tps(x = knots[[j]], knots = knots[[j]], m = m)
           nulldim <- ncol(Q) - nrow(Q)
           Xnull[[j]] <- X[,1:nulldim,drop=FALSE]
           Xcont[[j]] <- X[,(nulldim+1):ncol(X)]
