@@ -39,13 +39,13 @@ pred_rkhs <-
       } else if(tj == "nom"){
         
         # nominal smoothing spline
-        Xcont[[j]] <- basis_nom(x = factor(x[[j]], levels = xlev[[j]]), 
+        Xcont[[j]] <- basis.nom(x = factor(x[[j]], levels = xlev[[j]]), 
                                 knots = knots[[j]], K = xrng[[j]][2])
         
       } else if(tj == "ord"){
         
         # ordinal smoothing spline
-        Xcont[[j]] <- basis_ord(x = factor(x[[j]], levels = xlev[[j]], ordered = TRUE), 
+        Xcont[[j]] <- basis.ord(x = factor(x[[j]], levels = xlev[[j]], ordered = TRUE), 
                                 knots = knots[[j]], K = xrng[[j]][2])
         
       } else if(any(tj == ss.types)){
@@ -55,10 +55,10 @@ pred_rkhs <-
                     ifelse(tj == "cub" | tj == "per.cub" | tj == "per", 2L, 3L))
         periodic <- ifelse(any(tj == c("per.lin", "per.cub", "per.qui", "per")), TRUE, FALSE)
         if(periodic | tj == "lin"){
-          Xcont[[j]] <- basis_poly(x = x[[j]], knots = knots[[j]], m = m, xmin = xrng[[j]][1], xmax = xrng[[j]][2], periodic = periodic)
+          Xcont[[j]] <- basis.poly(x = x[[j]], knots = knots[[j]], m = m, xmin = xrng[[j]][1], xmax = xrng[[j]][2], periodic = periodic)
         } else {
-          X <- basis_poly(x = x[[j]], knots = knots[[j]], m = m, xmin = xrng[[j]][1], xmax = xrng[[j]][2], periodic = periodic)
-          Q <- basis_poly(x = knots[[j]], knots = knots[[j]][1], m = m, xmin = xrng[[j]][1], xmax = xrng[[j]][2], periodic = periodic)
+          X <- basis.poly(x = x[[j]], knots = knots[[j]], m = m, xmin = xrng[[j]][1], xmax = xrng[[j]][2], periodic = periodic)
+          Q <- basis.poly(x = knots[[j]], knots = knots[[j]][1], m = m, xmin = xrng[[j]][1], xmax = xrng[[j]][2], periodic = periodic)
           nulldim <- m - 1L
           nullnames <- xnames[j]
           if(m == 3L) nullnames <- c(nullnames, paste0(xnames[j], "^2"))
@@ -73,7 +73,7 @@ pred_rkhs <-
         
         # spherical spline
         m <- ifelse(tj == "sph.lin", 1L, ifelse(tj == "sph.cub" | tj == "sph", 2L, 3L))
-        Xcont[[j]] <- basis_sph(x = x[[j]], knots = knots[[j]], m = m)
+        Xcont[[j]] <- basis.sph(x = x[[j]], knots = knots[[j]], m = m)
         
       } else {
         
@@ -81,10 +81,10 @@ pred_rkhs <-
         xdim <- ncol(as.matrix(x[[j]]))
         m <- ifelse(tj == "tps.lin", 1L, ifelse(tj == "tps.cub" | tj == "tps", 2L, 3L))
         if(tj == "tps.lin"){
-          Xcont[[j]] <- basis_tps(x = x[[j]], knots = knots[[j]], m = m)
+          Xcont[[j]] <- basis.tps(x = x[[j]], knots = knots[[j]], m = m)
         } else {
-          X <- basis_tps(x = x[[j]], knots = knots[[j]], m = m)
-          Q <- basis_tps(x = knots[[j]], knots = knots[[j]], m = m)
+          X <- basis.tps(x = x[[j]], knots = knots[[j]], m = m)
+          Q <- basis.tps(x = knots[[j]], knots = knots[[j]], m = m)
           nulldim <- ncol(Q) - nrow(Q)
           Xnull[[j]] <- X[,1:nulldim,drop=FALSE]
           Xcont[[j]] <- X[,(nulldim+1):ncol(X)]
