@@ -2,7 +2,7 @@ summary.ss <-
   function(object, ...){
     # summary method for class "ss"
     # Nathaniel E. Helwig (helwig@umn.edu)
-    # Updated: 2019-12-08
+    # Updated: 2020-08-30
     
     # get residuals
     if(is.null(object$data)){
@@ -44,7 +44,8 @@ summary.ss <-
     
     # smooth coefficients table
     s.Fstat <- (ss / s.df) / object$sigma^2
-    s.pvals <- 1 - pf(s.Fstat, df1 = s.df, df2 = erdf)
+    #s.pvals <- 1 - pf(s.Fstat, df1 = s.df, df2 = erdf)
+    s.pvals <- 1 - pf(s.Fstat, df1 = pmax(s.df, 1), df2 = erdf)
     s.table <- rbind(c(s.df, ss, ss / s.df, s.Fstat, s.pvals),
                      c(erdf, erdf * object$sigma^2, object$sigma^2, NA, NA))
     colnames(s.table) <- c("Df", "Sum Sq", "Mean Sq", "F value", "Pr(>F)")
